#[repr(transparent)]pub struct MLReshapeFrequencyHint(pub NSInteger);MLReshapeFrequencyHint only.Expand description
The anticipated frequency of changing input shapes
See also Apple’s documentation
Tuple Fields
0: NSIntegerImplementations
Sourceimpl MLReshapeFrequencyHint
impl MLReshapeFrequencyHint
Sourcepub const Frequent: Self
pub const Frequent: Self
The input shape is expected to change frequently on each prediction sent to this loaded model instance. Core ML will try to minimize the latency associated with shape changes and avoid expensive shape-specific optimizations prior to prediction computation. While prediction computation may be slower for each specific shape, switching between shapes should be faster. This is the default.
Sourcepub const Infrequent: Self
pub const Infrequent: Self
The input shape is expected to be stable and many/all predictions sent to this loaded model instance would use the same input shapes repeatedly. On the shape change, Core ML re-optimizes the internal engine for the new shape if possible. The re-optimization takes some time, but the subsequent predictions for the shape should run faster.