pub unsafe trait MLComputeDeviceProtocol: NSObjectProtocol { }Available on crate feature
MLComputeDeviceProtocol only.Expand description
Protocol for representing a compute device. The represented device is capable of running machine learning computations and other tasks like analysis and processing of images, sound, etc.
See also Apple’s documentation