MLCustomLayer

Trait MLCustomLayer 

pub unsafe trait MLCustomLayer {
    // Provided methods
    unsafe fn initWithParameterDictionary_error(
        this: Allocated<Self>,
        parameters: &NSDictionary<NSString, AnyObject>,
    ) -> Result<Retained<Self>, Retained<NSError>>
       where Self: Sized + Message { ... }
    unsafe fn setWeightData_error(
        &self,
        weights: &NSArray<NSData>,
    ) -> Result<(), Retained<NSError>>
       where Self: Sized + Message { ... }
    unsafe fn outputShapesForInputShapes_error(
        &self,
        input_shapes: &NSArray<NSArray<NSNumber>>,
    ) -> Result<Retained<NSArray<NSArray<NSNumber>>>, Retained<NSError>>
       where Self: Sized + Message { ... }
    unsafe fn evaluateOnCPUWithInputs_outputs_error(
        &self,
        inputs: &NSArray<MLMultiArray>,
        outputs: &NSArray<MLMultiArray>,
    ) -> Result<(), Retained<NSError>>
       where Self: Sized + Message { ... }
    unsafe fn encodeToCommandBuffer_inputs_outputs_error(
        &self,
        command_buffer: &ProtocolObject<dyn MTLCommandBuffer>,
        inputs: &NSArray<ProtocolObject<dyn MTLTexture>>,
        outputs: &NSArray<ProtocolObject<dyn MTLTexture>>,
    ) -> Result<(), Retained<NSError>>
       where Self: Sized + Message { ... }
}
Available on crate feature MLCustomLayer only.
Provided Methods

unsafe fn initWithParameterDictionary_error( this: Allocated<Self>, parameters: &NSDictionary<NSString, AnyObject>, ) -> Result<Retained<Self>, Retained<NSError>>
where Self: Sized + Message,

Safety

parameters generic should be of the correct type.

unsafe fn setWeightData_error( &self, weights: &NSArray<NSData>, ) -> Result<(), Retained<NSError>>
where Self: Sized + Message,

unsafe fn outputShapesForInputShapes_error( &self, input_shapes: &NSArray<NSArray<NSNumber>>, ) -> Result<Retained<NSArray<NSArray<NSNumber>>>, Retained<NSError>>
where Self: Sized + Message,

unsafe fn evaluateOnCPUWithInputs_outputs_error( &self, inputs: &NSArray<MLMultiArray>, outputs: &NSArray<MLMultiArray>, ) -> Result<(), Retained<NSError>>
where Self: Sized + Message,

Available on crate feature MLMultiArray only.
unsafe fn encodeToCommandBuffer_inputs_outputs_error( &self, command_buffer: &ProtocolObject<dyn MTLCommandBuffer>, inputs: &NSArray<ProtocolObject<dyn MTLTexture>>, outputs: &NSArray<ProtocolObject<dyn MTLTexture>>, ) -> Result<(), Retained<NSError>>
where Self: Sized + Message,

Available on crate feature objc2-metal and non-watchOS only.
Safety
  • inputs generic may need to be synchronized.
  • inputs generic may be unretained, you must ensure it is kept alive while in use.
  • outputs generic may need to be synchronized.
  • outputs generic may be unretained, you must ensure it is kept alive while in use.